@@ -185,7 +185,7 @@ func getTerminalColumnsRequiredForString(str string) int {
 
 type jsonOutput struct {
 	Rows     []map[string]interface{}  `json:"rows"`
-	Metadata *queryresult.TimingResult `json:"metadata"`
+	Metadata *queryresult.TimingResult `json:"metadata,omitempty"`
 }
 
 func newJSONOutput() *jsonOutput {
@@ -402,13 +402,19 @@ func displayTable(ctx context.Context, result *queryresult.Result) (int, *queryr
 }
 
 func getTiming(result *queryresult.Result, count int) *queryresult.TimingResult {
-	if viper.GetString(constants.ArgTiming) == constants.ArgOff {
+	timingConfig := viper.GetString(constants.ArgTiming)
+
+	if timingConfig == constants.ArgOff || timingConfig == "false" {
 		return nil
 	}
 	// now we have iterated the rows, get the timing
 	timingResult := <-result.TimingResult
 	// set rows returned
 	timingResult.RowsReturned = int64(count)
+
+	if timingConfig != constants.ArgVerbose {
+		timingResult.Scans = nil
+	}
 	return timingResult
 }
 
