@@ -4,6 +4,7 @@ import {
   ExecutablePrimitiveProps,
   LeafNodeData,
 } from "../../common";
+import { DashboardRunState } from "../../../../types";
 
 export type CheckNodeType =
   | "benchmark"
@@ -20,7 +21,7 @@ export type CheckNodeType =
   | "status"
   | "tag";
 
-export interface CheckNode {
+export type CheckNode = {
   sort: string;
   name: string;
   title: string;
@@ -33,9 +34,7 @@ export interface CheckNode {
   data?: LeafNodeData;
   error?: string;
   merge?: (other: CheckNode) => void;
-}
-
-export type CheckNodeStatusRaw = "ready" | "started" | "complete" | "error";
+};
 
 export type CheckNodeStatus = "running" | "complete";
 
@@ -47,34 +46,31 @@ export type CheckSeveritySummary =
       [key in CheckSeverity]: number;
     };
 
-export interface CheckSummary {
+export type CheckSummary = {
   alarm: number;
   ok: number;
   info: number;
   skip: number;
   error: number;
-}
-export interface CheckLeafNodeDataGroupSummary {
-  status: CheckSummary;
-}
+};
 
-export interface CheckDynamicValueMap {
+export type CheckDynamicValueMap = {
   [dimension: string]: boolean;
-}
+};
 
-export interface CheckDynamicColsMap {
+export type CheckDynamicColsMap = {
   dimensions: CheckDynamicValueMap;
   tags: CheckDynamicValueMap;
-}
+};
 
-export interface CheckTags {
+export type CheckTags = {
   [key: string]: string;
-}
+};
 
-interface CheckResultDimension {
+type CheckResultDimension = {
   key: string;
   value: string;
-}
+};
 
 export type CheckResultStatus =
   | "alarm"
@@ -86,7 +82,7 @@ export type CheckResultStatus =
 
 export type CheckResultType = "loading" | "error" | "empty" | "result";
 
-export interface CheckResult {
+export type CheckResult = {
   dimensions: CheckResultDimension[];
   tags: CheckTags;
   control: CheckNode;
@@ -97,13 +93,13 @@ export interface CheckResult {
   severity?: CheckSeverity;
   error?: string;
   type: CheckResultType;
-}
+};
 
-interface CheckControlRunProperties {
+type CheckControlRunProperties = {
   severity?: CheckSeverity | undefined;
-}
+};
 
-export interface CheckControlRun {
+export type CheckControlRun = {
   name: string;
   title?: string;
   description?: string;
@@ -113,23 +109,9 @@ export interface CheckControlRun {
   tags?: CheckTags;
   data: LeafNodeData;
   summary: CheckSummary;
-  status: CheckNodeStatusRaw;
+  status: DashboardRunState;
   error?: string;
-}
-
-export type CheckGroupType = "benchmark" | "table";
-
-export interface CheckBenchmarkRun {
-  name: string;
-  title?: string;
-  description?: string;
-  panel_type: "benchmark";
-  tags?: CheckTags;
-  type: CheckGroupType;
-  source_definition: string;
-  summary: CheckLeafNodeDataGroupSummary;
-  children?: CheckBenchmarkRun[] | CheckControlRun[];
-}
+};
 
 export type CheckDisplayGroupType =
   | "benchmark"
@@ -142,10 +124,10 @@ export type CheckDisplayGroupType =
   | "severity"
   | "status";
 
-export interface CheckDisplayGroup {
+export type CheckDisplayGroup = {
   type: CheckDisplayGroupType;
   value?: string;
-}
+};
 
 export type BenchmarkTreeProps = BasePrimitiveProps &
   ExecutablePrimitiveProps & {
